<?php

/**
 * @file
 * Bartik's theme implementation to display a node.
 *
 * Available variables:
 * - $title: the (sanitized) title of the node.
 * - $content: An array of node items. Use render($content) to print them all,
 *   or print a subset such as render($content['field_example']). Use
 *   hide($content['field_example']) to temporarily suppress the printing of a
 *   given element.
 * - $user_picture: The node author's picture from user-picture.tpl.php.
 * - $date: Formatted creation date. Preprocess functions can reformat it by
 *   calling format_date() with the desired parameters on the $created variable.
 * - $name: Themed username of node author output from theme_username().
 * - $node_url: Direct url of the current node.
 * - $display_submitted: Whether submission information should be displayed.
 * - $submitted: Submission information created from $name and $date during
 *   template_preprocess_node().
 * - $classes: String of classes that can be used to style contextually through
 *   CSS. It can be manipulated through the variable $classes_array from
 *   preprocess functions. The default values can be one or more of the
 *   following:
 *   - node: The current template type, i.e., "theming hook".
 *   - node-[type]: The current node type. For example, if the node is a
 *     "Blog entry" it would result in "node-blog". Note that the machine
 *     name will often be in a short form of the human readable label.
 *   - node-teaser: Nodes in teaser form.
 *   - node-preview: Nodes in preview mode.
 *   The following are controlled through the node publishing options.
 *   - node-promoted: Nodes promoted to the front page.
 *   - node-sticky: Nodes ordered above other non-sticky nodes in teaser
 *     listings.
 *   - node-unpublished: Unpublished nodes visible only to administrators.
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 *
 * Other variables:
 * - $node: Full node object. Contains data that may not be safe.
 * - $type: Node type, i.e. story, page, blog, etc.
 * - $comment_count: Number of comments attached to the node.
 * - $uid: User ID of the node author.
 * - $created: Time the node was published formatted in Unix timestamp.
 * - $classes_array: Array of html class attribute values. It is flattened
 *   into a string within the variable $classes.
 * - $zebra: Outputs either "even" or "odd". Useful for zebra striping in
 *   teaser listings.
 * - $id: Position of the node. Increments each time it's output.
 *
 * Node status variables:
 * - $view_mode: View mode, e.g. 'full', 'teaser'...
 * - $teaser: Flag for the teaser state (shortcut for $view_mode == 'teaser').
 * - $page: Flag for the full page state.
 * - $promote: Flag for front page promotion state.
 * - $sticky: Flags for sticky post setting.
 * - $status: Flag for published status.
 * - $comment: State of comment settings for the node.
 * - $readmore: Flags true if the teaser content of the node cannot hold the
 *   main body content.
 * - $is_front: Flags true when presented in the front page.
 * - $logged_in: Flags true when the current user is a logged-in member.
 * - $is_admin: Flags true when the current user is an administrator.
 *
 * Field variables: for each field instance attached to the node a corresponding
 * variable is defined, e.g. $node->body becomes $body. When needing to access
 * a field's raw values, developers/themers are strongly encouraged to use these
 * variables. Otherwise they will have to explicitly specify the desired field
 * language, e.g. $node->body['en'], thus overriding any language negotiation
 * rule that was previously applied.
 *
 * @see template_preprocess()
 * @see template_preprocess_node()
 * @see template_process()
 */
?>
<div id="node-<?php print $node->nid; ?>" class="<?php print $classes; ?> clearfix"<?php print $attributes; ?>>

<?php if (!$page): ?>
	<header>  
		<?php print render($title_prefix); ?>
		<h1<?php print $title_attributes; ?>>
		  <a href="<?php print $node_url; ?>"><?php print $title; ?></a>
		</h1>
		<?php print render($title_suffix); ?>
		
		<div class="created-date"><span class="day"><?php print date('d',$created);?></span><span class="mon"><?php print date('M',$created);?></span><span class="year"><?php print date('Y',$created);?></span></div>
	  
	  <div class="title-bottom">
		  <?php if ($display_submitted): ?>
			<p class="submitted">
				<?php print '作者：'.$name; ?>
				<?php $statistics = statistics_get($node->nid); print format_plural($statistics['totalcount'], '点击数：<span>1</span>', '点击数：<span>@count</span>') ;?>
			</p>
		  <?php endif; ?>
		  <?php print render($content['field_tags']);?>
	  </div>
    </header>

	<section class="content clearfix"<?php print $content_attributes; ?>>
		<?php
		  // We hide the comments and links now so that we can render them later.
		  hide($content['comments']);
		  hide($content['links']);
		  print render($content);
		?>
	</section>
	<footer>
		<?php print l("阅读全文","node/".$node->nid,$options = array('attributes' => array('class' => array("node_read_more"))));?>
	</footer>
<?php endif; ?>

<?php if ($page): ?>
	<header>
		<?php print $user_picture; ?>
		<?php if ($display_submitted): ?>
			<section class="submitted">
			  <p><?php print $name;?></p>
			  <p><?php print date('Y-m-d',$created);?></p>
			  <p><?php $statistics = statistics_get($node->nid); print format_plural($statistics['totalcount'], '点击：<span>1</span>', '点击：<span>@count</span>') ;?></p>
			</section>
		<?php endif; ?>
		<?php print render($content['field_tags']);?>
		<?php print render($content['field_toupiao']);?>
	</header>
	<section class="content clearfix"<?php print $content_attributes; ?>>
		<?php
		  // We hide the comments and links now so that we can render them later.
		  hide($content['comments']);
		  hide($content['links']);
		  print render($content);
		?>
		<section id="alipay" class="block block-views block-alipay">
			<h2>小小赞助大大帮助</h2>
			<div class="views view-alipay">
				<div class="view-content">
					<p>如果您觉得本文的内容对您的学习有所帮助：</p>
					<p><a title="小小赞助大大帮助" href="http://me.alipay.com/w3cplus" target="_blank"><img align="absmiddle" width="159" height="37" alt="支付鼓励" src="http://www.w3cplus.com/sites/default/files/pay_encourage.png"></a></p>
				</div>
			</div>
		</section>
		<section id="googleAd" class="block block-views block-googlead">
			<h2>轻轻一点，是你对我的支持</h2>
			<div class="views view-google-ad">
				<div class="view-content">
					<script type="text/javascript"><!--
					google_ad_client = "ca-pub-6974442601598334";
					/* header */
					google_ad_slot = "0513434319";
					google_ad_width = 468;
					google_ad_height = 60;
					//-->
					</script>
					<script type="text/javascript"
					src="http://pagead2.googlesyndication.com/pagead/show_ads.js">
					</script>
				</div>				
			</div>
		</section>
		
		<!-- UJian Button BEGIN -->
		<div class="ujian-hook"></div>
		<script type="text/javascript" src="http://v1.ujian.cc/code/ujian.js?uid=1765"></script>
		<!-- UJian Button END -->
		 
		<!-- UY BEGIN -->
		<div id="uyan_frame"></div>
		<script type="text/javascript" id="UYScript" src="http://v1.uyan.cc/js/iframe.js?UYUserId=1765" async=""></script>
		<!-- UY END -->
	</section>
	
<?php endif; ?>

</div>
